SF.net SVN: geany-plugins:[1970] trunk/geany-plugins/geanygendoc/src/ ggd-options.c
colombanw at users.sourceforge.net
colombanw at xxxxx
Thu Mar 10 15:47:35 UTC 2011
Revision: 1970
http://geany-plugins.svn.sourceforge.net/geany-plugins/?rev=1970&view=rev
Author: colombanw
Date: 2011-03-10 15:47:35 +0000 (Thu, 10 Mar 2011)
Log Message:
-----------
GeanyGenDoc: don't shadow global declaration of read()
Modified Paths:
--------------
trunk/geany-plugins/geanygendoc/src/ggd-options.c
Modified: trunk/geany-plugins/geanygendoc/src/ggd-options.c
===================================================================
--- trunk/geany-plugins/geanygendoc/src/ggd-options.c 2011-03-09 06:41:13 UTC (rev 1969)
+++ trunk/geany-plugins/geanygendoc/src/ggd-options.c 2011-03-10 15:47:35 UTC (rev 1970)
@@ -458,7 +458,7 @@
/*
* ggd_opt_group_manage_key_file:
* @group: A #GgdOptGroup
* @read: Whether to read (%TRUE) or write (%FALSE) the group to or from the
* given key file
* @key_file: A #GKeyFile
*
@@ -466,7 +466,7 @@
*/
static void
ggd_opt_group_manage_key_file (GgdOptGroup *group,
- gboolean read,
+ gboolean load,
GKeyFile *key_file)
{
GgdOptEntry *entry;
@@ -478,7 +478,7 @@
case G_TYPE_BOOLEAN: {
gboolean *setting = (gboolean *)entry->optvar;
- if (read) {
+ if (load) {
gboolean v;
v = g_key_file_get_boolean (key_file, group->name, entry->key, &err);
@@ -494,7 +494,7 @@
case G_TYPE_STRING: {
gchar **setting = (gchar **)entry->optvar;
- if (read) {
+ if (load) {
gchar *str;
str = g_key_file_get_string (key_file, group->name, entry->key, &err);
@@ -517,7 +517,7 @@
group->name, entry->key, err->message);
g_error_free (err);
} else {
- if (read) {
+ if (load) {
ggd_opt_entry_sync_to_proxy (entry);
}
}
@@ -458,7 +458,7 @@
* ggd_opt_group_manage_key_file:
* @group: A #GgdOptGroup
- * @read: Whether to read (%TRUE) or write (%FALSE) the group to or from the
+ * @load: Whether to read (%TRUE) or write (%FALSE) the group to or from the
* given key file
* @key_file: A #GKeyFile
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
More information about the Plugins-Commits
mailing list